# metocean-stats

[![Documentation Status](https://readthedocs.org/projects/metocean-stats/badge/?version=latest)](https://metocean-stats.readthedocs.io/en/latest/?badge=latest)

## Purpose
Metocen stastistics

## Quick Installation

$ pip install metocean-stats 

## Docs
Information about the package can be found at the [documentation](https://metocean-stats.readthedocs.io/en/latest/index.html).
